@@ -5,6 +5,7 @@
 # Author: Wil Alvarez (aka Satanas)
 # May 26, 2010
 
+import ssl
 import urllib2
 import logging
 import traceback
@@ -14,9 +15,9 @@ from turpial.api.interfaces.http import TurpialHTTP, TurpialException
 from turpial.api.protocols.twitter.globals import POST_ACTIONS
 from turpial.api.protocols.twitter.globals import CONSUMER_KEY, CONSUMER_SECRET
 
-REQUEST_TOKEN_URL = 'http://api.twitter.com/oauth/request_token'
+REQUEST_TOKEN_URL = 'https://api.twitter.com/oauth/request_token'
 ACCESS_TOKEN_URL = 'https://api.twitter.com/oauth/access_token'
-AUTHORIZATION_URL = 'http://api.twitter.com/oauth/authorize'
+AUTHORIZATION_URL = 'https://api.twitter.com/oauth/authorize'
 
 class TwitterHTTP(TurpialHTTP):
     def __init__(self, apiurl):
@@ -171,6 +172,8 @@ class TwitterHTTP(TurpialHTTP):
                 )
             )
             raise TurpialException(_('Can\'t connect to Twitter'))
+        except ssl.SSLError:
+            raise TurpialException(_("SSL certificate doesn't match"))
         except Exception, exc:
             self.log.debug((
                 "Unknown error for URL:"
